@@ -17,8 +17,9 @@ class DefaultMiddleware(Middleware):
 class DefaultExceptionHandler:
     def __init__(self, app):
         self.app = app
+        self.dir_path = os.path.dirname(os.path.realpath(__file__))
         self.errors_env = Environment(
-            loader=FileSystemLoader("arc/selfpages"))
+            loader=FileSystemLoader(os.path.join(self.dir_path, "selfpages")))
 
     def handle_error(self, request, response, error):
         response.status_code = 500
